@@ -98,7 +98,7 @@ pub enum ItemProp {
 pub struct Action {
     uuid: Uuid,
     i: OID,
-    #[serde(deserialize_with = "eva_common::tools::deserialize_duration_from_micros")]
+    #[serde(deserialize_with = "eva_common::tools::deserialize_duration_from_nanos")]
     timeout: Duration,
     priority: u8,
     params: Option<actions::Params>,
